==> statistically-0.1.1.tar.gz: statistically-0.1.1/README.md <==
<h2 align="center">statistically: an empty-featured Stata output scraper/parser</h2>

<p align="center">
  <a href="https://www.gnu.org/licenses/agpl-3.0">
    <img alt="License: AGPL 3.0+" src="https://img.shields.io/badge/license-AGPL-009999.svg?style=flat-square" />
  </a>
  <a href="https://pypi.python.org/pypi/statistically">
    <img alt="Distributed via PyPI" src="https://img.shields.io/pypi/v/statistically?style=flat-square&color=009999" />
  </a>
  <a href="https://codeclimate.com/github/vaneseltine/statistically">
    <img alt="Maintainability rated at Code Climate" src="https://img.shields.io/codeclimate/maintainability-percentage/vaneseltine/statistically?style=flat-square">
  </a>
  <a href="https://coveralls.io/github/vaneseltine/statistically">
    <img alt="Test coverage at Coveralls" src="https://img.shields.io/coveralls/github/vaneseltine/statistically?style=flat-square" />
  </a>
  <a href="https://github.com/vaneseltine/statistically/actions">
    <img alt="Build at Github" src="https://img.shields.io/github/workflow/status/vaneseltine/statistically/Python%20package?style=flat-square" />
  </a>
  <a href="https://github.com/vaneseltine/statistically">
    <img alt="Latest commit at GitHub" src="https://img.shields.io/github/last-commit/vaneseltine/statistically?style=flat-square" />
  </a>
</p>

*statistically* is a Stata output parser. It's currently a rounding error away from useless.

### 🧙‍ Author

[![Matt VanEseltine](https://img.shields.io/badge/name-matt_vaneseltine-888.svg?style=for-the-badge&logo=linux&logoColor=fff&color=violet)](https://vaneseltine.github.io)

[![matvan@umich.edu](https://img.shields.io/badge/email-matvan@umich.edu-888.svg?style=for-the-badge&logo=gmail&logoColor=fff&color=00274c)](mailto:matvan@umich.edu)

[![https://orcid.org/0000-0002-9520-1360](https://img.shields.io/badge/orcid-0000.0002.9520.1360-green.svg?style=for-the-badge&logo=orcid&logoColor=#A6CE39&color=1da1f2)](https://orcid.org/0000-0002-9520-1360)

[![https://github.com/vaneseltine](https://img.shields.io/badge/github-vaneseltine-888.svg?style=for-the-badge&logo=github&logoColor=fff&color=2b3137)](https://github.com/vaneseltine)

[![https://pypi.org/user/matvan/](https://img.shields.io/badge/pypi-matvan-888.svg?style=for-the-badge&logo=python&logoColor=fff&color=0073b7)](https://pypi.org/user/matvan/)

[![https://twitter.com/vaneseltine](https://img.shields.io/badge/twitter-@vaneseltine-blue.svg?style=for-the-badge&logo=twitter&logoColor=fff&color=1da1f2)](https://twitter.com/vaneseltine)

==> statistically-0.1.3.tar.gz: statistically-0.1.3/README.md <==
<h2 align="center">statistically: an empty-featured Stata output scraper/parser</h2>

<p align="center">
  <a href="https://www.gnu.org/licenses/agpl-3.0">
    <img alt="License: AGPL 3.0+" src="https://img.shields.io/badge/license-AGPL-009999.svg?style=flat-square" />
  </a>
  <a href="https://pypi.python.org/pypi/statistically">
    <img alt="Distributed via PyPI" src="https://img.shields.io/pypi/v/statistically?style=flat-square&color=009999" />
  </a>
  <a href="https://codeclimate.com/github/vaneseltine/statistically">
    <img alt="Maintainability rated at Code Climate" src="https://img.shields.io/codeclimate/maintainability-percentage/vaneseltine/statistically?style=flat-square">
  </a>
  <a href="https://coveralls.io/github/vaneseltine/statistically">
    <img alt="Test coverage at Coveralls" src="https://img.shields.io/coveralls/github/vaneseltine/statistically/main?style=flat-square" />
  </a>
  <a href="https://github.com/vaneseltine/statistically/actions">
    <img alt="Build at Github" src="https://img.shields.io/github/workflow/status/vaneseltine/statistically/Python%20package?style=flat-square" />
  </a>
  <a href="https://github.com/vaneseltine/statistically">
    <img alt="Latest commit at GitHub" src="https://img.shields.io/github/last-commit/vaneseltine/statistically?style=flat-square" />
  </a>
</p>

*statistically* is a Stata output parser. It's currently a rounding error away from useless.

### 🧙‍ Author

[![Matt VanEseltine](https://img.shields.io/badge/name-matt_vaneseltine-888.svg?style=for-the-badge&logo=linux&logoColor=fff&color=violet)](https://vaneseltine.github.io)

[![matvan@umich.edu](https://img.shields.io/badge/email-matvan@umich.edu-888.svg?style=for-the-badge&logo=gmail&logoColor=fff&color=00274c)](mailto:matvan@umich.edu)

[![https://orcid.org/0000-0002-9520-1360](https://img.shields.io/badge/orcid-0000.0002.9520.1360-green.svg?style=for-the-badge&logo=orcid&logoColor=#A6CE39&color=1da1f2)](https://orcid.org/0000-0002-9520-1360)

[![https://github.com/vaneseltine](https://img.shields.io/badge/github-vaneseltine-888.svg?style=for-the-badge&logo=github&logoColor=fff&color=2b3137)](https://github.com/vaneseltine)

[![https://pypi.org/user/matvan/](https://img.shields.io/badge/pypi-matvan-888.svg?style=for-the-badge&logo=python&logoColor=fff&color=0073b7)](https://pypi.org/user/matvan/)

[![https://twitter.com/vaneseltine](https://img.shields.io/badge/twitter-@vaneseltine-blue.svg?style=for-the-badge&logo=twitter&logoColor=fff&color=1da1f2)](https://twitter.com/vaneseltine)
